%FILTRO QUE RESTAURA LA ENVOLVENTE.
%function srp=synfilt(drp,rrp)
%Entradas:
%drp:señal sin envolvente.
%rrp:coeficientes de reflexión.
%Salidas:
%srp:señal con envolvente.
function srp=synfilt(drp,rrp)
vr=zeros(1,8);
for k=1:160
   if(k<14)
      rrpaux=rrp(1:8);
   elseif(k<28)
      rrpaux=rrp(9:16);
   elseif(k<41)
      rrpaux=rrp(17:24);
   else
      rrpaux=rrp(25:32);
   end
   sr(1)=drp(k);
	for j=2:9
      sr(j)=sr(j-1)-rrpaux(10-j)*vr(10-j);
      v(11-j)=vr(10-j)+rrpaux(10-j)*sr(j);
   end
   srp(k)=sr(9);
   v(1)=sr(9);
   vr=v;
end